# mindstorm
[![PyPI version](https://badge.fury.io/py/mindstorm.svg)](https://badge.fury.io/py/mindstorm)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4248135.svg)](https://doi.org/10.5281/zenodo.4248135)

Package for advanced neuroimaging analysis tools.
